==> Net-Appliance-Session-3.111530.tar.gz: Net-Appliance-Session-3.111530/examples/example-1.pl <==
#!/usr/bin/perl -n

# This (fictional) example shows how you can save time if there are many
# devices that require manual login reconfiguration (e.g. no SNMP).
# 
# The program is a filter, so wants a list of hosts on standard input or a
# filename containing hosts as an argument, and will go through each one,
# connecting to and reconfiguring the device.

BEGIN {
    use strict;
    use warnings FATAL => 'all';

    use Net::Appliance::Session;
}

my $host = $_; chomp $host;
die "one and only param is a device FQDN or IP!\n"
    if ! defined $host;

my $s = Net::Appliance::Session->new(
    transport => 'SSH', # or 'Telnet' or 'Serial'
    personality => 'cisco', # or many others, see docs
    host => $host,
);
$s->set_global_log_at('debug'); # maximum debugging

eval {
    $s->connect(
        name     => $username,
        password => $password,
    );
    $s->begin_privileged; # use same pass as login

    # is this a device with FastEthernet or GigabitEthernet ports?
    # let's do a test and find out, for use in the later commands.

    my $type = $s->cmd('show interfaces status | incl 1/0/24');
    $type = ($type =~ m/^Gi/ ? 'GigabitEthernet' : 'FastEthernet');

    # now actually do some work...

    $s->begin_configure;

    $s->cmd("interface ${type}1/0/13");
    $s->cmd('spanning-tree bpdufilter enable');
    $s->cmd("interface ${type}1/0/14");
    $s->cmd('spanning-tree bpdufilter enable');
    $s->cmd("interface ${type}1/0/15");
    $s->cmd('spanning-tree bpdufilter enable');

    $s->end_configure;
    $s->cmd('write memory');
    $s->end_privileged;
};
warn $@ if $@;

$s->close;

==> Net-Appliance-Session-3.111590.tar.gz: Net-Appliance-Session-3.111590/examples/example-1.pl <==
#!/usr/bin/perl -n

# This (fictional) example shows how you can save time if there are many
# devices that require manual login reconfiguration (e.g. no SNMP).
# 
# The program is a filter, so wants a list of hosts on standard input or a
# filename containing hosts as an argument, and will go through each one,
# connecting to and reconfiguring the device.

BEGIN {
    use strict;
    use warnings FATAL => 'all';

    use Net::Appliance::Session;
}

my $host = $_; chomp $host;
die "one and only param is a device FQDN or IP!\n"
    if ! defined $host;

my $s = Net::Appliance::Session->new(
    transport => 'SSH', # or 'Telnet' or 'Serial'
    personality => 'ios', # or many others, see docs
    host => $host,
);
$s->set_global_log_at('debug'); # maximum debugging

eval {
    $s->connect(
        name     => $username,
        password => $password,
    );
    $s->begin_privileged; # use same pass as login

    # is this a device with FastEthernet or GigabitEthernet ports?
    # let's do a test and find out, for use in the later commands.

    my $type = $s->cmd('show interfaces status | incl 1/0/24');
    $type = ($type =~ m/^Gi/ ? 'GigabitEthernet' : 'FastEthernet');

    # now actually do some work...

    $s->begin_configure;

    $s->cmd("interface ${type}1/0/13");
    $s->cmd('spanning-tree bpdufilter enable');
    $s->cmd("interface ${type}1/0/14");
    $s->cmd('spanning-tree bpdufilter enable');
    $s->cmd("interface ${type}1/0/15");
    $s->cmd('spanning-tree bpdufilter enable');

    $s->end_configure;
    $s->cmd('write memory');
    $s->end_privileged;
};
warn $@ if $@;

$s->close;
